ExtentStomachPostCommentCompanion class

Constructors

ExtentStomachPostCommentCompanion({Value<int> graveManualGuardId = const i0.Value.absent(), Value<int> estateBrickLeafletUser = const i0.Value.absent(), Value<int> outputStageIndirectPost = const i0.Value.absent(), Value<String> outfitNearlyExactContent = const i0.Value.absent()})
const
ExtentStomachPostCommentCompanion.insert({Value<int> graveManualGuardId = const i0.Value.absent(), required int estateBrickLeafletUser, required int outputStageIndirectPost, required String outfitNearlyExactContent})

Properties

estateBrickLeafletUser → Value<int>
final
graveManualGuardId → Value<int>
final
hashCode int
The hash code for this object.
no setterinherited
outfitNearlyExactContent → Value<String>
final
outputStageIndirectPost → Value<int>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Value<int>? graveManualGuardId, Value<int>? estateBrickLeafletUser, Value<int>? outputStageIndirectPost, Value<String>? outfitNearlyExactContent}) ExtentStomachPostCommentCompanion
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toColumns(bool nullToAbsent) Map<String, Expression<Object>>
Converts this object into a map of column names to expressions to insert or update.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

custom({Expression<int>? graveManualGuardId, Expression<int>? estateBrickLeafletUser, Expression<int>? outputStageIndirectPost, Expression<String>? outfitNearlyExactContent}) → Insertable<ExtentStomachPostCommentEntity>