ExtentStomachPostCommentEntity class

Constructors

ExtentStomachPostCommentEntity({required int graveManualGuardId, required int estateBrickLeafletUser, required int outputStageIndirectPost, required String outfitNearlyExactContent})
const
ExtentStomachPostCommentEntity.fromJson(Map<String, dynamic> json, {ValueSerializer? serializer})
factory

Properties

estateBrickLeafletUser int
final
graveManualGuardId int
final
hashCode int
The hash code for this object.
no setteroverride
outfitNearlyExactContent String
final
outputStageIndirectPost int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? graveManualGuardId, int? estateBrickLeafletUser, int? outputStageIndirectPost, String? outfitNearlyExactContent}) ExtentStomachPostCommentEntity
copyWithCompanion(ExtentStomachPostCommentCompanion data) ExtentStomachPostCommentEntity
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toColumns(bool nullToAbsent) Map<String, Expression<Object>>
Converts this object into a map of column names to expressions to insert or update.
toJson({ValueSerializer? serializer}) Map<String, dynamic>
Converts this object into a representation that can be encoded with json. The serializer can be used to configure how individual values will be encoded. By default, DriftRuntimeOptions.defaultSerializer will be used. See ValueSerializer.defaults for details.
toJsonString({ValueSerializer? serializer}) String
Converts this object into a json representation. The serializer can be used to configure how individual values will be encoded. By default, DriftRuntimeOptions.defaultSerializer will be used. See ValueSerializer.defaults for details.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override