LiteracyBellyCabinQuestionEntity class

Constructors

LiteracyBellyCabinQuestionEntity({required int alarmBlankAbandonId, required String dribbleEffortSmokeContent, required String similarRidgeRelaxImage, required int panicMaximumToothUser, required String burialEarlierExpectTime, required bool reviveHonorForeignEmerge})
const
LiteracyBellyCabinQuestionEntity.fromJson(Map<String, dynamic> json, {ValueSerializer? serializer})
factory

Properties

alarmBlankAbandonId int
final
burialEarlierExpectTime String
final
dribbleEffortSmokeContent String
final
hashCode int
The hash code for this object.
no setteroverride
panicMaximumToothUser int
final
reviveHonorForeignEmerge bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
similarRidgeRelaxImage String
final

Methods

copyWith({int? alarmBlankAbandonId, String? dribbleEffortSmokeContent, String? similarRidgeRelaxImage, int? panicMaximumToothUser, String? burialEarlierExpectTime, bool? reviveHonorForeignEmerge}) LiteracyBellyCabinQuestionEntity
copyWithCompanion(LiteracyBellyCabinQuestionCompanion data) LiteracyBellyCabinQuestionEntity
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toColumns(bool nullToAbsent) Map<String, Expression<Object>>
Converts this object into a map of column names to expressions to insert or update.
toJson({ValueSerializer? serializer}) Map<String, dynamic>
Converts this object into a representation that can be encoded with json. The serializer can be used to configure how individual values will be encoded. By default, DriftRuntimeOptions.defaultSerializer will be used. See ValueSerializer.defaults for details.
toJsonString({ValueSerializer? serializer}) String
Converts this object into a json representation. The serializer can be used to configure how individual values will be encoded. By default, DriftRuntimeOptions.defaultSerializer will be used. See ValueSerializer.defaults for details.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override