ExtentStomachPostCommentEntity class
Constructors
-
const
-
factory
Methods
-
copyWith({int? graveManualGuardId, int? estateBrickLeafletUser, int? outputStageIndirectPost, String? outfitNearlyExactContent})
→ ExtentStomachPostCommentEntity
-
-
copyWithCompanion(ExtentStomachPostCommentCompanion data)
→ ExtentStomachPostCommentEntity
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toColumns(bool nullToAbsent)
→ Map<String, Expression<Object>>
-
Converts this object into a map of column names to expressions to insert
or update.
-
toJson({ValueSerializer? serializer})
→ Map<String, dynamic>
-
Converts this object into a representation that can be encoded with
json. The serializer can be used to configure how individual values
will be encoded. By default, DriftRuntimeOptions.defaultSerializer will
be used. See ValueSerializer.defaults for details.
-
toJsonString({ValueSerializer? serializer})
→ String
-
Converts this object into a json representation. The
serializer can be
used to configure how individual values will be encoded. By default,
DriftRuntimeOptions.defaultSerializer will be used. See
ValueSerializer.defaults for details.
inherited
-
toString()
→ String
-
A string representation of this object.
override