FactorEmptyReservoirMessageCompanion class
Constructors
-
FactorEmptyReservoirMessageCompanion({Value<
int> declineHandleTypicalId = const i0.Value.absent(), Value<String> verticalCoverRotateChat = const i0.Value.absent(), Value<String?> testifyBrakeScriptContent = const i0.Value.absent(), Value<String?> executePortraitSteepAudio = const i0.Value.absent(), Value<int> secretOccurLiteracyDuration = const i0.Value.absent()}) -
const
-
FactorEmptyReservoirMessageCompanion.insert({Value<
int> declineHandleTypicalId = const i0.Value.absent(), required String verticalCoverRotateChat, Value<String?> testifyBrakeScriptContent = const i0.Value.absent(), Value<String?> executePortraitSteepAudio = const i0.Value.absent(), Value<int> secretOccurLiteracyDuration = const i0.Value.absent()})
Properties
-
declineHandleTypicalId
→ Value<
int> -
final
-
executePortraitSteepAudio
→ Value<
String?> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
secretOccurLiteracyDuration
→ Value<
int> -
final
-
testifyBrakeScriptContent
→ Value<
String?> -
final
-
verticalCoverRotateChat
→ Value<
String> -
final
Methods
-
copyWith(
{Value< int> ? declineHandleTypicalId, Value<String> ? verticalCoverRotateChat, Value<String?> ? testifyBrakeScriptContent, Value<String?> ? executePortraitSteepAudio, Value<int> ? secretOccurLiteracyDuration}) → FactorEmptyReservoirMessageCompanion -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toColumns(
bool nullToAbsent) → Map< String, Expression< Object> > - Converts this object into a map of column names to expressions to insert or update.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited